@@ -7,7 +7,7 @@ import doctest
 
 from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import suite as test_suite
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 
 
@@ -21,7 +21,7 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             CommissionWaitingTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_commission_waiting.rst',
-            setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
